@@ -6,8 +6,8 @@ import (
 	"sync"
 	"time"
 
-	"github.com/vbauerster/mpb/v5"
-	"github.com/vbauerster/mpb/v5/decor"
+	"github.com/vbauerster/mpb/v6"
+	"github.com/vbauerster/mpb/v6/decor"
 )
 
 func main() {
@@ -19,9 +19,9 @@ func main() {
 
 	for i := 0; i < numBars; i++ {
 		name := fmt.Sprintf("Bar#%d:", i)
-		bar := p.AddBar(int64(total),
+		bar := p.Add(int64(total),
 			// reverse Bar#1
-			mpb.BarOptOn(mpb.BarReverse(), func() bool { return i == 1 }),
+			mpb.NewBarFillerPick("", i == 1),
 			mpb.PrependDecorators(
 				// simple name decorator
 				decor.Name(name),
